(*
 * <COPYRIGHT>
 * Copyright 2005 Gerd Stolpmann
 *
 * <GPL>
 * This file is part of UMLMON.
 *
 * UMLMON is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * UMLMON is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with UMLMON; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * </>
 *)

(* $Id: umlmon_auth.mli 187 2005-10-14 10:54:15Z gerd $ *)

(* Authentication API *)

open Umlmon_types
open Umlmonctrl_aux

val ensure_authenticated : Rpc_server.session -> unit
  (* Checks that the connection transporting the session is authenticated. Fails if not. *)

val forget_connection : Rpc_server.connection_id -> unit
  (* Deletes this session from the session cache. *)

val known_as_failed : Rpc_server.connection_id -> bool
  (* Whether authentication previously failed for the connection *)

val proc_auth_get_challenge :
  umlstatus -> 
  Rpc_server.session ->
  unit ->
  (string -> unit) ->
    unit
  (* Implements the [auth_get_challenge] procedure *)

val proc_auth_pass_credentials :
  Unixqueue.event_system ->
  umlstatus -> 
  Rpc_server.session ->
  (string * string array) ->
  (bool -> unit) ->
    unit
  (* Implements the [auth_pass_credentials] procedure *)

val proc_auth_reset :
  Unixqueue.event_system ->
  umlstatus -> 
  Rpc_server.session ->
  unit ->
  (unit -> unit) ->
    unit
  (* Implements the [auth_reset] procedure *)

val proc_auth_change_password :
  write_vm_config:(string -> umlspec -> unit) ->
  umlstatus -> 
  Rpc_server.session ->
  string ->
  (r_simple -> unit) ->
    unit
  (* Implements the [auth_change_password] procedure *)

